@@ -48,7 +48,7 @@ KiokuDB::Test - Reusable tests for L<KiokuDB> backend authors.
 
 =head1 SYNOPSIS
 
-    use Test::More 'no_plan';
+    use Test::More;
 
     use KiokuDB::Test;
 
@@ -58,6 +58,8 @@ KiokuDB::Test - Reusable tests for L<KiokuDB> backend authors.
 
     run_all_fixtures( KiokuDB->new( backend => $b ) );
 
+    done_testing();
+
 =head1 DESCRIPTION
 
 This module loads and runs L<KiokuDB::Test::Fixture>s against a L<KiokuDB>
